*07-09-2021*
**_ Reducing the Soleus Stretch Reflex with Conditioning: Exploring Game- and Impedance-based Biofeedback _**

# Introduction
For an optimal reading experience render this document with a Markdown parser.

This readme file describes the work presented in [1].

The work presents the exploration of the feasibility of two forms of biofeedback to obtain a within-session reduction of the Soleus stretch reflex with conditioning. First, we explored the feasibility of gamification and second, the feasibility of combined game- and impedance-based biofeedback.

In short, we showed feasibility of EMG-, game-based biofeedback within the operant conditioning paradigm, which calls for further research on gamification of conditioning paradigms to obtain improved participant motivation and engagement, while achieving long-term conditioning effects. Contrarily, the use of impedance-, game-based biofeedback did not result in a feasible conditioning paradigm, thus the time-intensiveness and slow learning curve of the conditioning paradigm remain an open challenge.

This document provides an overview of the documents, data and other materials and directs to other documentation that provides and explains more details.

# Contents
1. How to use
2. Contact
3. References
4. Licensing
5. Files

# How to use
This repository covers all documents related to the execution, analysis and reporting of the work published in [1]. The experiment was split across three groups, executed in seperate phases and referred to within this documentation as: 201906-07_ReplicateMrachacz ('Convential'-group), 201908-09_PilotMonkeyBusiness ('Gaming'-group) and 201911-12_PilotSystemIdentification ('Impedance'-group).

The *Code* folder contains all scripts/functions (MATLAB and R) and the *Data* folder contains all experimental data used within the project. The experiment was executed with the Achilles Perturbator device of the University of Twente. The scripts within the *Code* folder are further supported by functions in *Code/Functions* and intermediate stored data *Code/Processed*. Additional details about the code and data can be found in a readme within each respective folder: **_!README_code.md_** and **_!README_data.md_**).

## Prerequisites
The experiment was performed on a Dell Precision 3541 laptop with an Intel Core i7-9750H processor, 32 GB RAM, running Windows 10. The data analysis and processing was performed on a Dell Precision 3510 laptop with an Intel Core i7-6700HQ processor, 16 GB RAM, running Window 10.

All MATLAB code was created, tested and run in MATLAB/Simulink 2017b. All R code was created, tested and run in R3.6.2. For both MATLAB and R, the code might be forward compatible or easily adaptable to newer versions otherwise.

# Contact
For questions and suggestions, please contact either:

Edwin van Asseldonk (e.h.f.vanasseldonk@utwente.nl)
or
Ronald van 't Veld (r.c.vantveld@utwente.nl)

Department of Biomechanical Engineering  
Faculty of Engineering Technology  
University of Twente  
Enschede, The Netherlands  

# References
[1] van 't Veld RC, Flux E, Schouten AC, van der Krogt MM, van der Kooij H, van Asseldonk EHF. Reducing the Soleus Stretch Reflex with Conditioning: Exploring Game- and Impedance-based Biofeedback. doi: [10.3389/fresc.2021.742030](https://doi.org/10.3389/fresc.2021.742030)

# Licensing
"Reducing the Soleus Stretch Reflex with Conditioning: Exploring Game- and Impedance-based Biofeedback" (c) by van 't Veld RC, Flux E, Schouten AC, van der Krogt MM, van der Kooij H, van Asseldonk EHF
"Reducing the Soleus Stretch Reflex with Conditioning: Exploring Game- and Impedance-based Biofeedback" is licensed under a Creative Commons Attribution 4.0 International License.  
You should have received a copy of the license along with this work. If not, see [CC BY 4.0](http://creativecommons.org/licenses/by/4.0/).

The software within the *Code* folder is licensed under a MIT License.

# Files
- [Code]
  The *Code* folder contains the MATLAB and R scripts used during the experiment and afterwards during analysis. Moreover, the code folder includes all functions and intermediate stored data in support of the analysis scripts.
	- [Functions]
	The *Functions* folder contains all MATLAB functions in support of the analysis scripts.
		- alignSortEMGData.m
		- alignSortMechData.m
		- calcEMGTorqueCurve.m
		- calcHMCurve.m
		- calcMVC.m
		- dZOHLpFilter.m
		- getEMGStretchEnsembles.m
		- getMechStretchEnsembles.m
		- getStretchIndices.m
		- plotColors.m
		- plotHMCurve.m
		- plotStretchEnsembles.m
		- processBlocktoEnsemble.m
		- processMechtoEnsemble.m
		- subplotPositions.m
		- synchronizePosEMG.m
		- trimEMGEnsemble.m
		- trimMechEnsemble.m
	- [Processed]
	The *Processed* folder contains data files with intermediate results, stored to enable re-use across languages (MATLAB and R) and scripts.
		- [201906-07_ReplicateMrachacz]
			- outcomeMeasures.mat
		- [201908-09_PilotMonkeyBusiness]
			- outcomeMeasures.mat
		- [201911-12_PilotSystemIdentification]
			- outcomeMeasures.mat
		- dataTraining.mat
	- !LICENSE_code.md
	- !README_code.md
	- acclimatizationAnalysis.m
	- analyzeLM.m
	- analyzeLM.R
	- analyzeTimeseries.m
	- baselineAnalysis.m
	- conditioningAnalysis.m
- [Data]
The *Data* folder contains all experimental data from 9 participants, numbered Subject001 through Subject009. Note, the order of trial numbering as registered by the experimental GUI differs a bit between groups.
	- [201906-07_ReplicateMrachacz] / [201908-09_PilotMonkeyBusiness] / [201911-12_PilotSystemIdentification]
		- [Stretch_Acclimatization]
			- [Subject001 - Subject009]
				- [A01_SetZero]
					- Trial4C1R1.mat
				- [A05_CaliAchilles]
					- Trial3C1R1.mat
				- [A06_EMGMVC]
					- Trial2C1R1.mat
					- Trial2C1R2.mat
					- Trial2C1R3.mat
				- [A07_EMGTorqueCurve]
					- Trial5C1R1.mat
					- Trial5C2R1.mat
				- [E01_StimulusTest]
					- Trial1C1R1.mat
				- [E02_HMRecruitment]
					- Trial7C1R1.mat
				- [E03_ControlTrials]
					- Trial6C1R1.mat
				- Subject001.mat - Subject009.mat
			- AcrossSession.mat
			- Stretch_Acclimatization.mat
		- [Stretch_Baseline]
			- [Subject00X_Session01 - Session06]
				- [A01_SetZero]
					- Trial2C1R1.mat
				- [A05_CaliAchilles]
					- Trial1C1R1.mat
				- [A07_EMGTorqueCurve]
					- Trial3C1R1.mat
					- Trial3C2R1.mat
				- [E01_StimulusTest]
					- Trial4C1R1.mat
				- [E02_HMRecruitment]
					- Trial5C1R1.mat
				- [E03_ControlTrials]
					- Trial6C1R1.mat
					- Trial6C2R1.mat
					- Trial6C2R2.mat
					- Trial6C2R3.mat
				- Subject00X_Session01.mat - Subject00X_Session06.mat
			- Stretch_Baseline.mat
		- [Stretch_Conditioning]
			- [Subject00X_Session01 - Session06]
				- [A01_SetZero]
					- Trial2C1R1.mat
				- [A05_CaliAchilles]
					- Trial1C1R1.mat
				- [A07_EMGTorqueCurve]
					- Trial3C1R1.mat
					- Trial3C2R1.mat
				- [E01_StimulusTest]
					- Trial4C1R1.mat
				- [E02_HMRecruitment]
					- Trial5C1R1.mat
				- [E03_ControlTrials]
					- Trial6C1R1.mat
				- [E04_ConditioningTrials]
					- Trial7C1R1.mat
					- Trial7C1R2.mat
					- Trial7C1R3.mat
				- Subject00X_Session01.mat - Subject00X_Session06.mat
			- Stretch_Conditioning.mat
	- !LICENSE_data.md
	- !README.md
	- !README_data.md
	- IMI_Questionnaire_Scores.xlsx