# Introduction
The **_Code_** folder contains the MATLAB and R scripts used during the experiment and afterwards during analysis. Moreover, the code folder includes intermediate processed data, used directly in support of the code. This readme will focus on the post-experiment data analysis. The sections within this readme are in line with the subsections of the Results section in the article [1].

# Code Directory
- [Code]
	- [Functions]
	- [Processed]
		- [201906-07_ReplicateMrachacz]
			- outcomeMeasures.mat
		- [201908-09_PilotMonkeyBusiness]
			- outcomeMeasures.mat
		- [201911-12_PilotSystemIdentification]
			- outcomeMeasures.mat
		- dataTraining.mat
	- !LICENSE_code.md
	- !README.md
	- !README_code.md
	- acclimatizationAnalysis.m
	- analyzeLM.m
	- analyzeLM.R
	- analyzeTimeseries.m
	- baselineAnalysis.m
	- conditioningAnalysis.m
	
# Analysis Scripts
Note, the experiment was split across three groups, executed in seperate phases and referred to within this documentation as: 201906-07_ReplicateMrachacz ('Convential'-group), 201908-09_PilotMonkeyBusiness ('Gaming'-group) and 201911-12_PilotSystemIdentification ('Impedance'-group).

## Pre-Analysis
The *acclimatizationAnalysis.m*, *baselineAnalysis.m* and *conditioningAnalysis.m* scripts were used to convert all raw data into the outcome measures used for analysis. The scripts correspond to the three different type of sessions executed during the experiment, as stored in the **_Data_** directory. Note, these phases have been renamed within the manuscript as acclimatization => preliminary, baseline session 1 => acclimatization, baseline session 2-6 => baseline, conditioning => conditioning sessions. The *acclimatizationAnalysis.m* was performed during experiment execution as the MVC, EMG-torque curve, H-M recruitment curve and reflex EMG analysis results were all actively used to execute the remaining sessions, stored in the **_Data_** directory. The *baselineAnalysis.m* and *conditioningAnalysis.m* scripts extract all relevant outcome measures from the raw data, including: background activity (EMG/torque), reflex activity (EMG/impedance). As mentioned in the manuscript, some sessions were discarded due to EMG measurement artifacts (high amplitude noise across broad frequency range), as coded in these scripts. All outcome measures were stored per experimental group within the respected *Processed/outcomeMeasures.mat* files.

The *analyzeTimeseries.m* script was used to support the explanations within the manuscript method section, specifically the infographics of Figure 1 and 2, such that actual experimental data was used for visualization.

## Steadiness of Mmax and Background Activity
The *analyzeLM.m* was used to analyze the Mmax and background activity measures from the *Processed/outcomeMeasures.mat* files across all participants within the three experimental groups. Both the Mmax and background activity measures were visualized and analyzed by means of Figure 3 in the manuscript, generated by the *analyzeLM.m* script. The numerical results were stored within the *Processed/dataTraining.mat* file to support further statistical analysis as discussed in the other subsections.

## Soleus Stretch Reflex Reduction
The *analyzeLM.m* script was also used to analyze the reflexive outcome measures (specifically the EMG, the impedance measures are presented in the supplementary materials) from the *Processed/outcomeMeasures.mat* files. All reflexive measures were visualized by means of Figure 4 in the manuscript (and Figure S1 in the supplementary materials for the impedance). The numerical results were stored within the *Processed/dataTraining.mat* file. These numerical results from both the background activity and reflex activity analysis were used within the *analyzeLM.R* to execute the statistical analysis as summarized in Table 1. The statistical analysis includes the use of Linear Models including the background activity as covariates with contrast used to generate the final statistical results described in the manuscript.

## Necessity Acclimatization Session
The *analyzeLM.R* was also used for the statistical analysis of the acclimatization session, i.e. the inclusion of the A1 session as 6th baseline session. Similar to the main reflex reduction analysis, this analysis is based on the use of linear models and the use of contrasts to generate the final statistical results.

## Correlation EMG and Impedance-based Biofeedback
To analyze the two reflexive outcome measures (EMG / impedance), the correlation between both outcome measures was calculated in the *analyzeLM.m* script. Measures were normalized within-subject to be able to compute an overall correlation outcome for the Impedance group.

## Intrinsic Motivation Inventory
The intrinsic motivation inventory (IMI) analysis was executed outside of Matlab/R in excel using the *IMI_Questionnaire_Scores.xlsx* file as stored in the **_Data_** directory.

## Supporting Functions
The MATLAB functions supporting the analysis scripts elaborated on above are included in the **_Functions_** folder. The functions content will not be elaborated on in the readme and the reader is referred to the MATLAB-style function comments/explanations included general description and definitions of syntax, inputs and outputs. Finally, plots were exported using the export_fig function from the [Matlab File Exchange](https://nl.mathworks.com/matlabcentral/fileexchange/23629-export_fig).

# References
[1] van 't Veld RC, Flux E, Schouten AC, van der Krogt MM, van der Kooij H, van Asseldonk EHF. Reducing the Soleus Stretch Reflex with Conditioning: Exploring Game- and Impedance-based Biofeedback. doi: [10.3389/fresc.2021.742030](https://doi.org/10.3389/fresc.2021.742030)