function [EMGEns] = alignSortEMGData(DataEMG,TrialSettings,Settings)
%alignSortEMGData Align and sort the EMG data
%   Analyze the EMG data in the time-domain by aligning data at 
%   stretch/perturbation onsets from the digital trigger channel and
%   combining them into single ensemble. Function checks based on segment 
%   length whether enough data is available before/after index.
%
%	SYNTAX
%   [EMGEns] = alignSortEMGData(DataEMG,TrialSettings,Settings)
%
%	INPUTS
%   DataEMG       = Selection of EMG signals (struct)
%   TrialSettings = All settings used for current trial in AchillesGUI (struct)
%   Settings      = Overview of all processing settings (struct)
%
%   OUTPUT
%   EMGEns = Aligned and sorted EMG signals (struct)

    % Create processing settings and time vector
    segStartEMG = round(Settings.tSegStartEMG/DataEMG.dt); % [-] Samples before 
    segEndEMG = round(Settings.tSegEndEMG/DataEMG.dt); % [-] Samples after
    EMGEns.tSeg = (0:segEndEMG-1)'*DataEMG.dt;
    
    % Retrieve EMG start indices for stretch reflexes
    EMGEns.stretchIdxs = getStretchIndices(DataEMG.pos,TrialSettings);
    EMGEns.stretchIdxs = EMGEns.stretchIdxs((EMGEns.stretchIdxs > segStartEMG) & (EMGEns.stretchIdxs < (length(DataEMG.pos)-segEndEMG))); % Missing Achilles data

    % Pre-allocate ensemble data structure
    EMGEns.rise = struct('solBack',{},'taBack',{},'glBack',{},'gmBack',{},...
        'solReflex',{},'taReflex',{},'glReflex',{},'gmReflex',{},'posReflex',{});
    % Retrieve all the seperate EMG responses to all perturbations
    EMGEns.rise = getEMGStretchEnsembles(EMGEns.stretchIdxs,EMGEns.rise,...
        segStartEMG,segEndEMG,DataEMG.sol,DataEMG.ta,DataEMG.gm,DataEMG.gl,DataEMG.pos);
end