function [stretchIdxs] = getStretchIndices(posRefEMG,TrialSettings)
%getStretchIndices Retrieve mechanical/EMG start indices for stretch reflexes
%   Retrieve all the stretch reflex start indices, located by centering
%   around the midpoint of the perturbation.
%
%   SYNTAX
%   [stretchIdxs] = getStretchIndices(posRefEMG,TrialSettings)
%
%	INPUTS
%   posRefEMG     = Reference position vector from EMG (Mx1 double)
%   TrialSettings = All settings used for current trial in AchillesGUI (struct)
%
%   OUTPUT
%   stretchIdxs = Set of stretch/perturbation onset indices (Nx1 double)

    % Find triggers for EMG, Locate all stretches and center around the midpoint of perturbation
    if (strcmp(TrialSettings.feedbackMode,'SysID'))
        posHigh = find(posRefEMG > 0.0175) - 28;
    else   
        posHigh = find(posRefEMG > 0.06969) - 72;
    end
    stretchIdxs = posHigh([true; (diff(posHigh) > 1)]);
end