function plotHMCurve(varargin)
%plotHMCurve Plot H-M recruitment curve
%   Plot the calculated H-M recruitment curve (ensemble averaged), incl.
%   visualization of windows and time-domain response
%
%	SYNTAX
%   plotHMCurve(DataHM,TrialSettings,SessionSettings) {Online}
%   plotHMCurve(OutputData)                           {Post-trial}
%
%	INPUTS
%   DataHM          = Selection of H-M Recruitment curve data (struct)
%   TrialSettings   = All settings used for current trial in AchillesGUI (struct)
%   SessionSettings = All settings used for current session in AchillesGUI (struct)
%   OutputData      = Complete set of experimental data (struct)

    % Retrieve all relevant outputs for post-trial analysis
    if (nargin == 1)
        OutputData = varargin{1};
        DataHM = calcHMCurve(OutputData.EMGData,OutputData.TrialSettings,OutputData.SessionSettings);
        TrialSettings = OutputData.TrialSettings;
        SessionSettings = OutputData.SessionSettings;
    elseif (nargin == 3)
        DataHM = varargin{1};
        TrialSettings = varargin{2};
        SessionSettings = varargin{3};
    end

    % Plot H-M recruitment curve (ensemble averaged)
    figure;
    subplot(2,1,1)
        hold on;
        plot(DataHM.t,mean(DataHM.solResponse,3)/1000,'LineWidth',1)
    if isfield(SessionSettings.AcrossSession,'mWaveWindow')
        % Extended if H-M recruitment curve windows are available already
        yLim = get(gca,'YLim');
        plot([SessionSettings.AcrossSession.mWaveWindow(1) SessionSettings.AcrossSession.mWaveWindow(1)]/TrialSettings.fsEMG,yLim,'--','Color',[0 0.447 0.741],'LineWidth',1)
        plot([SessionSettings.AcrossSession.mWaveWindow(2) SessionSettings.AcrossSession.mWaveWindow(2)]/TrialSettings.fsEMG,yLim,'--','Color',[0 0.447 0.741],'LineWidth',1)
        plot([SessionSettings.AcrossSession.hReflexWindow(1) SessionSettings.AcrossSession.hReflexWindow(1)]/TrialSettings.fsEMG,yLim,'--','Color',[0.85 0.325 0.098],'LineWidth',1)
        plot([SessionSettings.AcrossSession.hReflexWindow(2) SessionSettings.AcrossSession.hReflexWindow(2)]/TrialSettings.fsEMG,yLim,'--','Color',[0.85 0.325 0.098],'LineWidth',1)
    end
        title('Ensemble Response')
        xlabel('Time [s]')
        ylabel('Response [mV]')
    if isfield(SessionSettings.AcrossSession,'mWaveWindow')
        % Extended if H-M recruitment curve windows are available already
        subplot(2,1,2)
            hold on;
            plot(SessionSettings.AcrossSession.stimIntensities,mean(DataHM.mWaveSize,2)/1000,'^','LineWidth',1);
            plot(SessionSettings.AcrossSession.stimIntensities,mean(DataHM.hReflexSize,2)/1000,'o','LineWidth',1);
            title(['H-M Recruitment Curve: M-max = ' num2str(max(mean(DataHM.mWaveSize,2)/1000),'%.1f') ' [mV]'])
            xlabel('Stimulation Amplitude [mA]')
            ylabel('Response [mV]')
            legend({'M-Wave','H-Reflex'})
    end
end