function [MechEns] = trimMechEnsemble(MechEns,TrialSettings,trialIdxs)
%trimMechEnsemble Remove transients from Mechanical ensembled data 
%   Trim the ensembled Mechanical dataset by removing the initial transient
%   part of each block.
%
%	SYNTAX
%   MechEns = trimMechEnsemble(MechEns,TrialSettings,SysID)
%
%	INPUTS
%   MechEns       = Aligned and sorted (bio)mechanical signals (struct)
%   TrialSettings = All settings used for current trial in AchillesGUI (struct)
%   trialIdxs     = Indices of all perturbation/feedback moments (Mx1 double)
%
%   OUTPUT
%   MechEns = Aligned and sorted (bio)mechanical signals (struct)

    % Remove transients from ensemble data (start 5 seconds before first feedback-index)
    startStopIdxs = (MechEns.stretchIdxs >= (trialIdxs(1) - 5*TrialSettings.fsAch) & MechEns.stretchIdxs < (trialIdxs(end) + 0.2*TrialSettings.fsAch));
    % Trim the entire ensemble with all (sub-)structures eliminating
    % indices within the transient periods
    MechEns.stretchIdxs = MechEns.stretchIdxs(startStopIdxs);
    MechEns.rise = structfun(@(x) x(:,startStopIdxs),MechEns.rise,'UniformOutput',false);
end