%% Clean Start
clc, clearvars, close all;

%% Settings
% Experiment and Subject IDs to-be processed
Settings.experimentID = {'201906-07_ReplicateMrachacz','201908-09_PilotMonkeyBusiness','201911-12_PilotSystemIdentification'}; % Experiment identifier
Settings.subjectID = [{'001','002','003'};{'004','005','006'};{'007','008','009'}]; % Subject identifier (padded to 3 numbers)
% Experimental and processing settings (flags)
Settings.feedbackMode = {'EMG','EMG','SysID'}; % Flag if feedback provided on 'EMG' or 'SysID'
Settings.isPlot = 0; % Flag to generate plots during processing (if true)
% Define data storage location
dataCD = cd; fileSepIdxs = strfind(dataCD,filesep);
dataCD = dataCD(1:fileSepIdxs(end)-1);

% Add folder with all shared functions
addpath(genpath('Functions'));

%% Processing
for ii = 1:numel(Settings.experimentID)
    % Clear all variables per Experiment
    clearvars -except ii dataCD Settings
    for jj = size(Settings.subjectID,1):-1:1
        %% MVC
        % Retrieve path/name of all MVC trials 
        dirContent = dir([dataCD '/Data/' Settings.experimentID{ii} '/Stretch_Acclimatization/Subject' Settings.subjectID{ii,jj} '/A06_EMGMVC/*.mat']);
        dirContent = {dirContent.name}';
        % Pre-allocate per-trial MVC
        trialMVC = zeros(numel(dirContent),1);

        for kk = 1:numel(dirContent)
            % Load trial data and process to calculate MVC value
            load([dataCD '/Data/' Settings.experimentID{ii} '/Stretch_Acclimatization/Subject' Settings.subjectID{ii,jj} '/A06_EMGMVC/' dirContent{kk}]);
            trialMVC(kk) = calcMVC(OutputData);
        end
        AcrossSession(jj,1).MVC = round(max(trialMVC),1);

        %% EMG-Torque Curve
        % Retrieve path/name of all EMG-Torque curve trials
        dirContent = dir([dataCD '/Data/' Settings.experimentID{ii} '/Stretch_Acclimatization/Subject' Settings.subjectID{ii,jj} '/A07_EMGTorqueCurve/*.mat']);
        dirContent = {dirContent.name}';

        % Load first (plantarflexion) curve and plot result
        load([dataCD '/Data/' Settings.experimentID{ii} '/Stretch_Acclimatization/Subject' Settings.subjectID{ii,jj} '/A07_EMGTorqueCurve/' dirContent{1}]);
        calcEMGTorqueCurve(OutputData,Settings);

        % Generate (subject-specific) background torque bounds roughly around
        % 4/5Nm torque for EMG and 4Nm for torque
        if (strcmp(Settings.subjectID{ii,jj},'003'))
            AcrossSession(jj).boundsBackSol = [0.025 0.075]; % [%MVC] Feedback window bounds
        elseif (any(strcmp(Settings.subjectID{ii,jj},{'005','006'})))
            AcrossSession(jj).boundsBackSol = [0.04 0.09];
        elseif (any(strcmp(Settings.subjectID{ii,jj},{'007','009'})))
            AcrossSession(jj).boundsBackSol = [0.075 0.125];
        else
            AcrossSession(jj).boundsBackSol = [0.05 0.1];    % [%MVC] Feedback window bounds
        end
        if (strcmp(Settings.feedbackMode{ii},'SysID'))
            AcrossSession(jj).boundsBackTq = [3.5 4.5]; % [Nm] Feedback window bounds
        else
            AcrossSession(jj).boundsBackTq = [NaN NaN];
        end

        %% H-M Recruitment curve
        % Retrieve path/name of all H-M recruitment curve trials
        dirContent = dir([dataCD '/Data/' Settings.experimentID{ii} '/Stretch_Acclimatization/Subject' Settings.subjectID{ii,jj} '/E02_HMRecruitment/*.mat']);
        dirContent = {dirContent.name}';

        % Generate M-Wave and H-Reflex windows around peak-to-peak values
        % Also, create stimulation intensity spacing: start at 0, continue with
        % small increments around upward flank of H-reflex, end with 3 M-max with 5
        % mA increments
        switch Settings.subjectID{ii,jj}
            case '001'
                AcrossSession(jj).mWaveWindow = [8 53]; % [-] Samples after trigger for M-wave
                AcrossSession(jj).hReflexWindow = [73 103]; % [-] Samples after trigger for H-reflex
                AcrossSession(jj).stimIntensities = [0;15;(20:2:38)';(55:5:65)']; % [mA] Stimulation amplitudes
            case '002'
                AcrossSession(jj).mWaveWindow = [8 53];
                AcrossSession(jj).hReflexWindow = [63 93];
                AcrossSession(jj).stimIntensities = [0;5;(10:18)';(30:5:40)'];
            case '003'
                AcrossSession(jj).mWaveWindow = [6 51];
                AcrossSession(jj).hReflexWindow = [58 88];
                AcrossSession(jj).stimIntensities = [0;3;(5:12)';(15:5:25)'];
            case '004'
                AcrossSession(jj).mWaveWindow = [6 51];
                AcrossSession(jj).hReflexWindow = [58 88];
                AcrossSession(jj).stimIntensities = [0;(30:5:40)'];
            case '005'
                AcrossSession(jj).mWaveWindow = [8 53];
                AcrossSession(jj).hReflexWindow = [61 91];
                AcrossSession(jj).stimIntensities = [0;(40:5:50)'];
            case '006'
                AcrossSession(jj).mWaveWindow = [8 53];
                AcrossSession(jj).hReflexWindow = [64 94];
                AcrossSession(jj).stimIntensities = [0;(45:5:55)'];
            case '007'
                AcrossSession(jj).mWaveWindow = [8 53];
                AcrossSession(jj).hReflexWindow = [64 94];
                AcrossSession(jj).stimIntensities = [0;(20:5:30)'];
            case '008'
                AcrossSession(jj).mWaveWindow = [8 53];
                AcrossSession(jj).hReflexWindow = [61 91];
                AcrossSession(jj).stimIntensities = [0;(40:5:50)'];
            case '009'
                AcrossSession(jj).mWaveWindow = [8 53]; % [-] Samples after trigger for M-wave
                AcrossSession(jj).hReflexWindow = [61 91]; % [-] Samples after trigger for H-reflex
                AcrossSession(jj).stimIntensities = [0;(60:5:70)']; % [mA] Stimulation amplitudes
        end

        % Load last curve and plot result
        load([dataCD '/Data/' Settings.experimentID{ii} '/Stretch_Acclimatization/Subject' Settings.subjectID{ii,jj} '/E02_HMRecruitment/' dirContent{end}]);
        OutputData.SessionSettings.AcrossSession.mWaveWindow = AcrossSession(jj).mWaveWindow;
        OutputData.SessionSettings.AcrossSession.hReflexWindow = AcrossSession(jj).hReflexWindow;
        plotHMCurve(OutputData);

        %% Control Trials
        % Retrieve path/name of all H-M recruitment curve trials
        dirContent = dir([dataCD '/Data/' Settings.experimentID{ii} '/Stretch_Acclimatization/Subject' Settings.subjectID{ii,jj} '/E03_ControlTrials/*.mat']);
        dirContent = {dirContent.name}';

        switch Settings.subjectID{ii,jj}
            case '001'
                AcrossSession(jj).M1Window = [102 122]; % [-] Samples after trigger for M1 reflex
            case '002'
                AcrossSession(jj).M1Window = [90 110];
            case '003'
                AcrossSession(jj).M1Window = [82 102];
            case '004'            
                AcrossSession(jj).M1Window = [86 106];
            case '005'
                AcrossSession(jj).M1Window = [93 113];
            case '006'
                AcrossSession(jj).M1Window = [95 115];
            case '007'
                AcrossSession(jj).M1Window = [89 109];
            case '008'
                AcrossSession(jj).M1Window = [92 112];
            case '009'
                AcrossSession(jj).M1Window = [92 112];  % [-] Samples after trigger for M1 reflex
        end

        % Load and plot first set of results
        load([dataCD '/Data/' Settings.experimentID{ii} '/Stretch_Acclimatization/Subject' Settings.subjectID{ii,jj} '/E03_ControlTrials/' dirContent{1}]);
        OutputData.SessionSettings.AcrossSession.M1Window = AcrossSession(jj).M1Window;
        if (strcmp(Settings.feedbackMode{ii},'SysID'))
            OutputData.SysID.trialIdxs = [30*2048 size(OutputData.AchData,1) - 6*2048]';
        end
        plotStretchEnsembles(OutputData);
    end

    %% Save Results
%     save([dataCD '/Data/' Settings.experimentID{ii} '/Stretch_Acclimatization/AcrossSession2.mat'],'AcrossSession','-v7.3');
end