# General Preperation ####
#Load all relevant libraries
library(R.matlab)
library(multcomp)
library(lme4)
library(lmerTest)

# Section LM: Sol M1 Block0 ####
# Empty workspace
rm(list = ls())
# Data Preparation
data <- readMat('Processed/dataTraining.mat')
dataset <- setNames(as.data.frame(data$datasetTraining,col),c("subID","sessID","blockID","mMax","stimInterval","solBack","taBack","tqBack","solM1","solM1Norm","ankleG","ankleGNorm"))
rm(data)
# Select relevent dataset elements (Block 0 of Sessions A1-B5) and factorize ID elements
dataset <- dataset[dataset$blockID==0&dataset$sessID<6,]
dataset$subID <- factor(dataset$subID)
dataset$sessID <- factor(dataset$sessID)
# RM-ANOVA Sol M1 Block0 /w contrasts (reverse-Helmert)
my.helmert <- solve(t(matrix(c(rep(1/6,6),1,rep(-1/5,5),0,1,rep(-1/4,4),rep(0,2),1,rep(-1/3,3),rep(0,3),1,rep(-1/2,2),rep(0,4),1,-1),ncol=6)))
block0Model <- lm(solM1Norm ~ sessID,data = dataset,contrasts=list(sessID=my.helmert[,2:6]))
# Summarizing test section
summary(block0Model)
drop1(block0Model,test="F")
hist(resid(block0Model))
plot(block0Model,which = c(1,2),ask=FALSE)
plot(resid(block0Model)~dataset$sessID)
plot(resid(block0Model)~dataset$subID)

# Section LM: Sol M1 ####
# Empty workspace
rm(list = ls())
# Data Preparation
data <- readMat('Processed/dataTraining.mat')
dataset <- setNames(as.data.frame(data$datasetStretches,col),c("subID","sessID","blockID","solBack","taBack","tqBack","solM1"))
rm(data)
# Select relevent dataset elements (Sessions B1-C6) and factorize ID elements
dataset <- dataset[dataset$sessID!=0,]
dataset$subID <- factor(dataset$subID)
dataset$sessID <- factor(dataset$sessID)
dataset$blockID <- factor(dataset$blockID)

# Manually iterate over all subjects
subj <- 1
# Select relevant data elements
if ((subj <= 6) || (subj == 9)){
  subjDataset <- dataset[dataset$subID==subj,]
} else if (subj == 7){ # Remove session B1/B5 for subject 7/8, respectively, as essential control block is missing
  subjDataset <- dataset[dataset$subID==subj & dataset$sessID!=1,]
} else {
  subjDataset <- dataset[dataset$subID==subj & dataset$sessID!=5,]
}
# Create linear models with and without background activation covariates
solM1Model <- lm(solM1 ~ sessID*blockID,data=subjDataset)
solM1Cov   <- lm(solM1 ~ sessID*blockID+solBack+taBack+tqBack,data=subjDataset)
# Create within-session conditioning contrast (Block0 vs. Block1-3 and B1-5 vs. C4-6)
if ((subj <= 6) || (subj == 9)){
  contrastSetup <- matrix(c(rep(0,14),rep(c(rep(-1/15,4),rep(0,3),rep(1/9,3)),3)), 1)
  contrCovSetup <- matrix(c(rep(0,17),rep(c(rep(-1/15,4),rep(0,3),rep(1/9,3)),3)), 1)
} else {
  contrastSetup <- matrix(c(rep(0,13),rep(c(rep(-1/12,3),rep(0,3),rep(1/9,3)),3)), 1)
  contrCovSetup <- matrix(c(rep(0,16),rep(c(rep(-1/12,3),rep(0,3),rep(1/9,3)),3)), 1)
}
# Execute within-session conditioning contrast
trainingContrast <- glht(solM1Model, linfct=contrastSetup)
trainingContrCov <- glht(solM1Cov, linfct=contrCovSetup)

# Summarizing test section
hist(resid(solM1Model)) # Normality Residuals
plot(solM1Model,which = c(1,2),ask=FALSE)
plot(resid(solM1Model)~subjDataset$sessID)
summary(solM1Model)

hist(resid(solM1Cov)) # Normality Residuals
plot(solM1Cov,which = c(1,2),ask=FALSE)
plot(resid(solM1Cov)~subjDataset$sessID)
summary(solM1Cov)

summary(trainingContrast)
summary(trainingContrCov)