%% Clean Start
clc, clearvars, close all;

%% Settings
% Experiment and Subject IDs to-be processed
Settings.experimentID = {'201906-07_ReplicateMrachacz','201908-09_PilotMonkeyBusiness','201911-12_PilotSystemIdentification'}; % Experiment identifier
% Experimental and processing settings (flags)
Settings.feedbackMode = 'Mixed'; % Flag if feedback provided on 'EMG' or 'SysID' or 'Mixed'
Settings.isPlot = 1; % Flag to generate plots during processing (if true)

% Add folder with all shared functions
addpath(genpath('Functions'));

% Load data
for ii = numel(Settings.experimentID):-1:1
    expLoad(ii,1) = load(['Processed/' Settings.experimentID{ii} '/outcomeMeasures.mat']);
end
% Concatenate data across several participant groups for processing
AcrossSession = vertcat(expLoad.AcrossSession);
ResultsBaseline = vertcat(expLoad.ResultsBaseline);
ResultsCondition = vertcat(expLoad.ResultsCondition);
Settings.numSubjects = numel(ResultsBaseline);

%% Convert to Statistics Table
%%% Training per session/block
dataTraining = table;
% Create subject, session and block IDs
dataTraining.subID = repelem((1:9)',12*4);
dataTraining.sessID = repmat(repelem((0:11)',4),9,1);
dataTraining.blockID = repmat(repmat((0:3)',12,1),9,1);
% Distribute mMax across all table entries
dataTraining.mMax = repelem(reshape([cat(2,ResultsBaseline.mMax); cat(2,ResultsCondition.mMax)],[],1),4)/1000; %[mV]
fieldNames = {'stimInterval','solBack','taBack','tqBack','solM1','solM1Norm','ankleG','ankleGNorm'};
for ii = 1:numel(fieldNames)
    % Reshape all relevant fields into table format
    dataTraining.(fieldNames{ii}) = reshape([reshape(cat(1,ResultsBaseline.(fieldNames{ii}))',6*4,[]); reshape(cat(1,ResultsCondition.(fieldNames{ii}))',6*4,[])],[],1);
end
datasetTraining = table2array(dataTraining);
%%% Training per session/block/stretch
dataStretches = table;
for ii = 1:Settings.numSubjects
    subjDataStretches = table;
    % Check total number of stretches per subject (variable within last subject group)
    numSubjStretches = [cellfun(@numel,ResultsBaseline(ii).solBackBlock); cellfun(@numel,ResultsCondition(ii).solBackBlock)];
    % Create subject, session and block IDs
    subjDataStretches.subID = repelem(ii,sum(numSubjStretches(:)))';
    subjDataStretches.sessID = repelem((0:11)',sum(numSubjStretches,2));
    subjDataStretches.blockID = repelem(repmat((0:3)',12,1),reshape(numSubjStretches',[],1));
    fieldNames = {'solBackBlock','taBackBlock','tqBackBlock'};
    for jj = 1:numel(fieldNames)
        % Reshape all relevant fields into table format
        subjDataStretches.(fieldNames{jj}) = cell2mat(reshape([ResultsBaseline(ii).(fieldNames{jj}); ResultsCondition(ii).(fieldNames{jj})]',[],1));
        subjDataStretches.(fieldNames{jj}) = subjDataStretches.(fieldNames{jj}) - mean(subjDataStretches.(fieldNames{jj}),'omitnan');
    end
    subjDataStretches.solM1BlockNorm = cell2mat(reshape([[ResultsBaseline(ii).solM1BlockControlNorm, ResultsBaseline(ii).solM1BlockCondNorm]; [ResultsCondition(ii).solM1BlockControlNorm, ResultsCondition(ii).solM1BlockCondNorm]]',[],1));
    dataStretches = [dataStretches;subjDataStretches]; %#ok<AGROW>
end
datasetStretches = table2array(dataStretches);
% save([cd '/Processed/dataTraining2'],'datasetTraining','datasetStretches')

%% Figure 3 (Constant Variables)
plotWidth    = 16.6;
plotHeight   = 10;
marginLeft   = 0.75;
marginRight  = 0.1;
marginBottom = 0.4;
marginTop    = 0.3;
nPlotX       = 3;
nPlotY       = 4;
spacingX     = 0.2;
spacingY     = 0.25;
fontSize     = 8;
fontName     = 'Segoe UI';
subjMarkers  = {'o-','s--','d-.'};
hAx = gobjects(12,1);

% Define data
subjMMax = reshape(dataTraining.mMax(1:4:end),[],9);
subjBackSol = reshape(mean(reshape(dataTraining.solBack,4,[]),'omitnan'),[],9);
subjBackTa = reshape(mean(reshape(dataTraining.taBack,4,[]),'omitnan'),[],9);
subjBackTq = reshape(mean(reshape(dataTraining.tqBack,4,[]),'omitnan'),[],9);
% Generation of Figure 3A H-M Recruitment Curve
figure('Units','centimeters','Position',[4 4 plotWidth plotHeight],'Color','w');
posSubplots = subplotPositions(plotWidth,plotHeight,marginLeft,marginRight,marginBottom,marginTop,nPlotX,nPlotY,spacingX,spacingY);
for ii = 1:3
    hAx(ii) = axes('position',posSubplots{9+ii},'FontSize',fontSize,'FontName',fontName,'Layer','top'); hold on; box on;
    for jj = 1:3
        kk = (ii-1)*3 + jj; % Subject counter
        plot((-0.2+jj*0.1)+(7:12),subjMMax(7:12,kk),subjMarkers{jj},'Color',plotColors(ii,'dark'),'MarkerSize',5,'Linewidth',1);
        plot((-0.2+jj*0.1)+(2:7),subjMMax(2:7,kk),subjMarkers{jj},'Color',plotColors(ii),'MarkerSize',5,'Linewidth',1);
        plot((-0.2+jj*0.1)+(1:2),subjMMax(1:2,kk),subjMarkers{jj},'Color',plotColors(ii,'light'),'MarkerSize',5,'Linewidth',1);
    end
    ylim([0 10]);
end
% Generation of Figure 3B Background Soleus
for ii = 1:3
    hAx(ii+3) = axes('position',posSubplots{6+ii},'FontSize',fontSize,'FontName',fontName,'Layer','top'); hold on; box on;
    for jj = 1:3
        kk = (ii-1)*3 + jj; % Subject counter
        plot((-0.2+jj*0.1)+(7:12),subjBackSol(7:12,kk),subjMarkers{jj},'Color',plotColors(ii,'dark'),'MarkerSize',5,'Linewidth',1);
        plot((-0.2+jj*0.1)+(2:7),subjBackSol(2:7,kk),subjMarkers{jj},'Color',plotColors(ii),'MarkerSize',5,'Linewidth',1);
        plot((-0.2+jj*0.1)+(1:2),subjBackSol(1:2,kk),subjMarkers{jj},'Color',plotColors(ii,'light'),'MarkerSize',5,'Linewidth',1);
    end
    ylim([0 15]);
end
% Generation of Figure 3C Background Tibialis
for ii = 1:3
    hAx(ii+6) = axes('position',posSubplots{3+ii},'FontSize',fontSize,'FontName',fontName,'Layer','top'); hold on; box on;
    for jj = 1:3
        kk = (ii-1)*3 + jj; % Subject counter
        plot((-0.2+jj*0.1)+(7:12),subjBackTa(7:12,kk),subjMarkers{jj},'Color',plotColors(ii,'dark'),'MarkerSize',5,'Linewidth',1);
        plot((-0.2+jj*0.1)+(2:7),subjBackTa(2:7,kk),subjMarkers{jj},'Color',plotColors(ii),'MarkerSize',5,'Linewidth',1);
        plot((-0.2+jj*0.1)+(1:2),subjBackTa(1:2,kk),subjMarkers{jj},'Color',plotColors(ii,'light'),'MarkerSize',5,'Linewidth',1);
    end
    set(hAx(ii+6),'YLim',[0 8],'YTick',0:2:8);
end
% Generation of Figure 3D Background Torque
for ii = 1:3
    hAx(ii+9) = axes('position',posSubplots{ii},'FontSize',fontSize,'FontName',fontName,'Layer','top'); hold on; box on;
    for jj = 1:3
        kk = (ii-1)*3 + jj; % Subject counter
        plot((-0.2+jj*0.1)+(7:12),subjBackTq(7:12,kk),subjMarkers{jj},'Color',plotColors(ii,'dark'),'MarkerSize',5,'Linewidth',1);
        plot((-0.2+jj*0.1)+(2:7),subjBackTq(2:7,kk),subjMarkers{jj},'Color',plotColors(ii),'MarkerSize',5,'Linewidth',1);
        plot((-0.2+jj*0.1)+(1:2),subjBackTq(1:2,kk),subjMarkers{jj},'Color',plotColors(ii,'light'),'MarkerSize',5,'Linewidth',1);
    end
    set(hAx(ii+9),'YLim',[-8 0],'YTick',-8:2:0);
end
    
for ii = 1:numel(hAx)
    yLimits = get(hAx(ii),'YLim');
    plot(hAx(ii),[6.5 6.5],[yLimits(1) yLimits(2)],'--','Color',plotColors(10));
    plot(hAx(ii),[1.5 1.5],[yLimits(1) yLimits(2)],'--','Color',plotColors(10));
    if (mod(ii,3) ~= 1), set(hAx(ii),'YTickLabel',[]); end
    set(hAx(ii),'XLim',[0 13],'XTick',1:12)
    if (ii < 10)
        set(hAx(ii),'XTickLabel',[]);
    else
        set(hAx(ii),'XTickLabel',{'A1','B1','','','','B5','C1','','','','','C6'});
    end
    switch ii
        case 1
            hYLabel(1) = ylabel(hAx(ii),'SOL M_{max} (mV)');
            title(hAx(ii),'Conventional');
        case 2
            title(hAx(ii),'Gaming');
        case 3
            title(hAx(ii),'Impedance');
        case 4
            hYLabel(2) = ylabel(hAx(ii),'SOL Back. (nV)');
        case 7
            hYLabel(3) = ylabel(hAx(ii),'TA Back. (nV)');
        case 10
            hYLabel(4) = ylabel(hAx(ii),'Tq Back. (Nm)');
    end
    set(hAx(ii),'Children',flipud(get(hAx(ii),'Children')));
end
hYLabel(1).Position(1) = -0.9;
for ii = 2:numel(hYLabel), hYLabel(ii).Position(1) = -1.2; end %#ok<SAGROW>

% export_fig([cd '/Processed/OutcomeFigures/Fig3_ConstantVariables'],'-pdf','-painters');

%% Figure 4 (Reflex Variables)
plotWidth    = 16.6;
plotHeight   = 8;
marginLeft   = 1.35;
marginRight  = 0.1;
marginBottom = 0.4;
marginTop    = 0.3;
nPlotX       = 3;
nPlotY       = 3;
spacingX     = 0.2;
spacingY     = 0.25;
fontSize     = 8;
fontName     = 'Segoe UI';
subjMarkers  = {'o-','s--','d-.'};
hAx = gobjects(9,1);

% Define data
subjCondM1 = reshape(mean(reshape(dataTraining.solM1Norm(dataTraining.blockID~=0),3,[]),'omitnan'),[],9);
subjControlM1 = reshape(dataTraining.solM1Norm(dataTraining.blockID==0),[],9);
subjWithinM1 = subjCondM1 - subjControlM1;
% Generation of Figure 4A Conditioned Reflex
figure('Units','centimeters','Position',[4 4 plotWidth plotHeight],'Color','w');
posSubplots = subplotPositions(plotWidth,plotHeight,marginLeft,marginRight,marginBottom,marginTop,nPlotX,nPlotY,spacingX,spacingY);
for ii = 1:3
    hAx(ii) = axes('position',posSubplots{6+ii},'FontSize',fontSize,'FontName',fontName,'Layer','top'); hold on; box on;
    for jj = 1:3
        kk = (ii-1)*3 + jj; % Subject counter
        plot((-0.2+jj*0.1)+(7:12),subjCondM1(7:12,kk),subjMarkers{jj},'Color',plotColors(ii,'dark'),'MarkerSize',5,'Linewidth',1);
        plot((-0.2+jj*0.1)+(2:7),subjCondM1(2:7,kk),subjMarkers{jj},'Color',plotColors(ii),'MarkerSize',5,'Linewidth',1);
        plot((-0.2+jj*0.1)+(1:2),subjCondM1(1:2,kk),subjMarkers{jj},'Color',plotColors(ii,'light'),'MarkerSize',5,'Linewidth',1);
    end
    ylim([0 200]);
    plot(hAx(ii),[0 13],[100 100],'--','Color',plotColors(10));
end
% Generation of Figure 4B Control Reflex
posSubplots = subplotPositions(plotWidth,plotHeight,marginLeft,marginRight,marginBottom,marginTop,nPlotX,nPlotY,spacingX,spacingY);
for ii = 1:3
    hAx(ii+3) = axes('position',posSubplots{3+ii},'FontSize',fontSize,'FontName',fontName,'Layer','top'); hold on; box on;
    for jj = 1:3
        kk = (ii-1)*3 + jj; % Subject counter
        plot((-0.2+jj*0.1)+(7:12),subjControlM1(7:12,kk),subjMarkers{jj},'Color',plotColors(ii,'dark'),'MarkerSize',5,'Linewidth',1);
        plot((-0.2+jj*0.1)+(2:7),subjControlM1(2:7,kk),subjMarkers{jj},'Color',plotColors(ii),'MarkerSize',5,'Linewidth',1);
        plot((-0.2+jj*0.1)+(1:2),subjControlM1(1:2,kk),subjMarkers{jj},'Color',plotColors(ii,'light'),'MarkerSize',5,'Linewidth',1);
    end
    ylim([0 200]);
    plot(hAx(ii+3),[0 13],[100 100],'--','Color',plotColors(10));
end
% Generation of Figure 4C Within-Session Effect
posSubplots = subplotPositions(plotWidth,plotHeight,marginLeft,marginRight,marginBottom,marginTop,nPlotX,nPlotY,spacingX,spacingY);
for ii = 1:3
    hAx(ii+6) = axes('position',posSubplots{ii},'FontSize',fontSize,'FontName',fontName,'Layer','top'); hold on; box on;
    for jj = 1:3
        kk = (ii-1)*3 + jj; % Subject counter
        plot((-0.2+jj*0.1)+(7:12),subjWithinM1(7:12,kk),subjMarkers{jj},'Color',plotColors(ii,'dark'),'MarkerSize',5,'Linewidth',1);
        plot((-0.2+jj*0.1)+(2:7),subjWithinM1(2:7,kk),subjMarkers{jj},'Color',plotColors(ii),'MarkerSize',5,'Linewidth',1);
        plot((-0.2+jj*0.1)+(1:2),subjWithinM1(1:2,kk),subjMarkers{jj},'Color',plotColors(ii,'light'),'MarkerSize',5,'Linewidth',1);
    end
    ylim([-75 75]);
    plot(hAx(ii+6),[0 13],[0 0],'--','Color',plotColors(10));
    patch([6.5 13 13 6.5],[-15 -15 -75 -75],plotColors(10,8),'EdgeColor','none');
end

for ii = 1:numel(hAx)
    yLimits = get(hAx(ii),'YLim');
    plot(hAx(ii),[6.5 6.5],[yLimits(1) yLimits(2)],'--','Color',plotColors(10));
    plot(hAx(ii),[1.5 1.5],[yLimits(1) yLimits(2)],'--','Color',plotColors(10));
    if (mod(ii,3) ~= 1), set(hAx(ii),'YTickLabel',[]); end
    set(hAx(ii),'XLim',[0 13],'XTick',1:12)
    if (ii < 7)
        set(hAx(ii),'XTickLabel',[]);
    else
        set(hAx(ii),'XTickLabel',{'A1','B1','','','','B5','C1','','','','','C6'});
    end
    switch ii
        case 1
            hYLabel2(1) = ylabel(hAx(ii),{'Cond. Reflex','(% Baseline)'});
            title(hAx(ii),'Conventional');
        case 2
            title(hAx(ii),'Gaming');
        case 3
            title(hAx(ii),'Impedance');
        case 4
            hYLabel2(2) = ylabel(hAx(ii),{'Control Reflex','(% Baseline)'});
        case 7
            hYLabel2(3) = ylabel(hAx(ii),{'Cond. - Control','Reflex'});
    end
    set(hAx(ii),'Children',flipud(get(hAx(ii),'Children')));
end
for ii = 1:numel(hYLabel2), hYLabel2(ii).Position(1) = -1.55; end %#ok<SAGROW>

% export_fig([cd '/Processed/OutcomeFigures/Fig4_ReflexVariables'],'-pdf','-painters');

%% Figure 5 (Feedback Correlations)
plotWidth    = 7.8;
plotHeight   = 4.6;
marginLeft   = 0.8;
marginRight  = 0.1;
marginBottom = 0.5;
marginTop    = 0;
nPlotX       = 2;
nPlotY       = 1;
spacingX     = 0.3;
spacingY     = 0;
fontSize     = 8;
fontName     = 'Segoe UI';
subjColors   = [plotColors(3,'dark'); plotColors(3); plotColors(3,'light')];
xLimits = [-4 4]; yLimits = [-4 4];
rng(9);

% Define data
% Within-block reflex correlations
blockCorr = []; countM1GWithin = 0;
for ii = 7:9
    % Retrieve datapoints
    subjBlockGM1Base = reshape(permute(ResultsBaseline(ii).fbPerfCond(2:6,:,:,:),[3 4 1 2]),75,[]);
    subjBlockGM1Base = subjBlockGM1Base(:,~any(isnan(subjBlockGM1Base)));
    subjBlockGM1Cond = reshape(permute(ResultsCondition(ii).fbPerfCond,[3 4 1 2]),75,[]);
    % Sort and standardize
    corrBlock = [reshape(zscore(subjBlockGM1Base(:,[1:2:end 2:2:end])),[],2); reshape(zscore(subjBlockGM1Cond(:,[1:2:end 2:2:end])),[],2)];
    randBlock = randperm(size(corrBlock,1),ceil(size(corrBlock,1)/10))';
    countM1GWithin = [countM1GWithin; countM1GWithin(end) + ceil(size(corrBlock,1)/10)]; %#ok<AGROW>
    blockCorr = [blockCorr; corrBlock(randBlock,:)]; %#ok<AGROW>
end
% Across-block reflex correlations
sessionCorr = []; countM1GAcross = 0;
for ii = 7:9
    % Retrieve datapoints
    subjSessGM1 = [dataTraining.ankleG(dataTraining.subID==ii&dataTraining.sessID~=0&dataTraining.blockID~=0),dataTraining.solM1(dataTraining.subID==ii&dataTraining.sessID~=0&dataTraining.blockID~=0)];
    % Remove NaN (per set of datapoints solM1-ankleG)
    countM1GAcross = [countM1GAcross; countM1GAcross(end) + sum(~any(isnan(subjSessGM1),2))]; %#ok<AGROW>
    % Standardize and add together
    subjSessGM1 = zscore(subjSessGM1(~any(isnan(subjSessGM1),2),:));
    sessionCorr = [sessionCorr; subjSessGM1]; %#ok<AGROW>
end

% Generation of Figure 3A Within-block correlations
figure('Units','centimeters','Position',[4 4 plotWidth plotHeight],'Color','w');
posSubplots = subplotPositions(plotWidth,plotHeight,marginLeft,marginRight,marginBottom,marginTop,nPlotX,nPlotY,spacingX,spacingY);
axes('position',posSubplots{1},'FontSize',fontSize,'FontName',fontName,'Layer','top'); hold on; box off;
	plot(xLimits,[0 0],'--','Color',plotColors(10)); plot([0 0],yLimits,'--','Color',plotColors(10));
    for ii = 1:3
        plot(blockCorr((countM1GWithin(ii)+1):countM1GWithin(ii+1),1),blockCorr((countM1GWithin(ii)+1):countM1GWithin(ii+1),2),'.','Color',subjColors(ii,:),'Linewidth',1);
    end
    axis([xLimits, yLimits],'square');
    xlabel('Reflex Gain (x)');
    ylabel('SOL M1 (x)');
    title(['Within-block (r = ' num2str(corr(blockCorr(:,1),blockCorr(:,2)),2) ')']);
% Generation of Figure 3B Across-block correlations
axes('position',posSubplots{2},'FontSize',fontSize,'FontName',fontName,'Layer','top'); hold on; box off;
	plot(xLimits,[0 0],'--','Color',plotColors(10)); plot([0 0],yLimits,'--','Color',plotColors(10));
    for ii = 1:3
        plot(sessionCorr((countM1GAcross(ii)+1):countM1GAcross(ii+1),1),sessionCorr((countM1GAcross(ii)+1):countM1GAcross(ii+1),2),'.','Color',subjColors(ii,:),'Linewidth',1);
    end
    axis([xLimits, yLimits],'square');
    xlabel('Reflex Gain (x)');
    yticklabels([]);
    title(['Across-block (r = ' num2str(corr(sessionCorr(:,1),sessionCorr(:,2)),2) ')']);
    
% export_fig([cd '/Processed/OutcomeFigures/Fig5_FeedbackCorrelation'],'-pdf','-painters');

%% Figure S1 (AnkleG Reflex Variables)
plotWidth    = 6.367;
plotHeight   = 8;
marginLeft   = 1.35;
marginRight  = 0.1;
marginBottom = 0.4;
marginTop    = 0.3;
nPlotX       = 1;
nPlotY       = 3;
spacingX     = 0.2;
spacingY     = 0.25;
fontSize     = 8;
fontName     = 'Segoe UI';
subjMarkers  = {'o-','s--','d-.'};
hAx = gobjects(3,1);

% Define data
subjCondG = reshape(mean(reshape(dataTraining.ankleGNorm(dataTraining.blockID~=0),3,[]),'omitnan'),[],9);
subjControlG = reshape(dataTraining.ankleGNorm(dataTraining.blockID==0),[],9);
subjWithinG = subjCondG - subjControlG;
% Generation of Figure S1A Conditioned Reflex
figure('Units','centimeters','Position',[4 4 plotWidth plotHeight],'Color','w');
posSubplots = subplotPositions(plotWidth,plotHeight,marginLeft,marginRight,marginBottom,marginTop,nPlotX,nPlotY,spacingX,spacingY);
hAx(1) = axes('position',posSubplots{3},'FontSize',fontSize,'FontName',fontName,'Layer','top'); hold on; box on;
for jj = 1:3
    plot((-0.2+jj*0.1)+(7:12),subjCondG(7:12,jj+6),subjMarkers{jj},'Color',plotColors(3,'dark'),'MarkerSize',5,'Linewidth',1);
    plot((-0.2+jj*0.1)+(2:7),subjCondG(2:7,jj+6),subjMarkers{jj},'Color',plotColors(3),'MarkerSize',5,'Linewidth',1);
    plot((-0.2+jj*0.1)+(1:2),subjCondG(1:2,jj+6),subjMarkers{jj},'Color',plotColors(3,'light'),'MarkerSize',5,'Linewidth',1);
end
ylim([0 250]);
plot(hAx(1),[0 13],[100 100],'--','Color',plotColors(10));
hYLabel2(1) = ylabel(hAx(1),{'Cond. Reflex','(% Baseline)'});
title(hAx(1),'Impedance (\itGain G\rm\bf)');
% Generation of Figure S1B Control Reflex
posSubplots = subplotPositions(plotWidth,plotHeight,marginLeft,marginRight,marginBottom,marginTop,nPlotX,nPlotY,spacingX,spacingY);
hAx(2) = axes('position',posSubplots{2},'FontSize',fontSize,'FontName',fontName,'Layer','top'); hold on; box on;
for jj = 1:3
    plot((-0.2+jj*0.1)+(7:12),subjControlG(7:12,jj+6),subjMarkers{jj},'Color',plotColors(3,'dark'),'MarkerSize',5,'Linewidth',1);
    plot((-0.2+jj*0.1)+(2:7),subjControlG(2:7,jj+6),subjMarkers{jj},'Color',plotColors(3),'MarkerSize',5,'Linewidth',1);
    plot((-0.2+jj*0.1)+(1:2),subjControlG(1:2,jj+6),subjMarkers{jj},'Color',plotColors(3,'light'),'MarkerSize',5,'Linewidth',1);
end
ylim([0 250]);
plot(hAx(2),[0 13],[100 100],'--','Color',plotColors(10));
hYLabel2(2) = ylabel(hAx(2),{'Control Reflex','(% Baseline)'});
% Generation of Figure S1C Within-Session Effect
posSubplots = subplotPositions(plotWidth,plotHeight,marginLeft,marginRight,marginBottom,marginTop,nPlotX,nPlotY,spacingX,spacingY);
hAx(3) = axes('position',posSubplots{1},'FontSize',fontSize,'FontName',fontName,'Layer','top'); hold on; box on;
for jj = 1:3
    plot((-0.2+jj*0.1)+(7:12),subjWithinG(7:12,jj+6),subjMarkers{jj},'Color',plotColors(3,'dark'),'MarkerSize',5,'Linewidth',1);
    plot((-0.2+jj*0.1)+(2:7),subjWithinG(2:7,jj+6),subjMarkers{jj},'Color',plotColors(3),'MarkerSize',5,'Linewidth',1);
    plot((-0.2+jj*0.1)+(1:2),subjWithinG(1:2,jj+6),subjMarkers{jj},'Color',plotColors(3,'light'),'MarkerSize',5,'Linewidth',1);
end
ylim([-75 75]);
plot(hAx(3),[0 13],[0 0],'--','Color',plotColors(10));
hYLabel2(3) = ylabel(hAx(3),{'Cond. - Control','Reflex'});
patch([6.5 13 13 6.5],[-15 -15 -75 -75],plotColors(10,8),'EdgeColor','none');

for ii = 1:numel(hAx)
    yLimits = get(hAx(ii),'YLim');
    plot(hAx(ii),[6.5 6.5],[yLimits(1) yLimits(2)],'--','Color',plotColors(10));
    plot(hAx(ii),[1.5 1.5],[yLimits(1) yLimits(2)],'--','Color',plotColors(10));
    set(hAx(ii),'XLim',[0 13],'XTick',1:12)
    if (ii < 3)
        set(hAx(ii),'XTickLabel',[]);
    else
        set(hAx(ii),'XTickLabel',{'A1','B1','','','','B5','C1','','','','','C6'});
    end
    set(hAx(ii),'Children',flipud(get(hAx(ii),'Children')));
end
for ii = 1:numel(hYLabel2), hYLabel2(ii).Position(1) = -1.55; end 

% export_fig([cd '/Processed/OutcomeFigures/FigS1_ReflexImpedance'],'-pdf','-painters');