%% Clean Start
clc, clearvars, close all;

%% Settings
% Define data storage directory
dataCD = cd; fileSepIdxs = strfind(dataCD,filesep);
dataCD = dataCD(1:fileSepIdxs(end)-1);
% Define data storage location from the 2 representative subjects (2 and
% 8); Data taken from the second data acquisition session (B1)
dataSetDisc = [dataCD '/Data/201906-07_ReplicateMrachacz/Stretch_Baseline/Subject002_Session02/E03_ControlTrials/Trial6C2R1.mat'];
dataSetCont = [dataCD '/Data/201911-12_PilotSystemIdentification/Stretch_Baseline/Subject008_Session02/E03_ControlTrials/Trial6C2R1.mat'];
dataSession = [dataCD '/Data/201906-07_ReplicateMrachacz/Stretch_Acclimatization/AcrossSession.mat'];

% Add folder with all shared functions
addpath(genpath('Functions'));

%% Load & Process data
% Load across-session data (Subj 2 plot only)
load(dataSession);

% Load data from representative trial
load(dataSetDisc);
% Process experimental block to EMG/Mechanical ensembled data
[Disc.EMGEns,Disc.DataEMG]   = processBlocktoEnsemble(OutputData.EMGData,OutputData.TrialSettings);
[Disc.MechEns,Disc.DataMech] = processMechtoEnsemble(OutputData.AchData,OutputData.TrialSettings,OutputData.SessionSettings);
OutputData.TrialSettings.pertAmplitude = OutputData.TrialSettings.stepAmpl;
% Get EMG-translated time-vector (note, stretchIdxs inputs are dummy, non-functional, simply to let function execute)
[~,Disc.DataEMG.t]           = trimEMGEnsemble(Disc.EMGEns,OutputData.AchData,OutputData.EMGData,OutputData.TrialSettings,Disc.EMGEns.stretchIdxs(1:74),Disc.MechEns.stretchIdxs(5:end-4));

% Load data from representative trial
load(dataSetCont);
% Process experimental block to EMG/Mechanical ensembled data
[Cont.EMGEns,Cont.DataEMG]   = processBlocktoEnsemble(OutputData.EMGData,OutputData.TrialSettings);
[Cont.MechEns,Cont.DataMech] = processMechtoEnsemble(OutputData.AchData,OutputData.TrialSettings,OutputData.SessionSettings);
% Get EMG-translated time-vector (note, trial/stretchIdxs inputs are dummy, non-functional, simply to let function execute)
[~,Cont.DataEMG.t]           = trimEMGEnsemble(Cont.EMGEns,OutputData.AchData,OutputData.EMGData,OutputData.TrialSettings,OutputData.SysID.trialIdxs,Cont.MechEns.stretchIdxs(5:end-4));

%% Figure 1 (Exp. Overview)
%%% Figure 1C (Timeseries: Discrete/Continuous perturbation and responses)
% Settings
plotWidth    = 9.6;
plotHeight   = 5.1;
marginLeft   = 1.45;
marginRight  = 0.1;
marginBottom = 0.85;
marginTop    = 0.1;
nPlotX       = 2;
nPlotY       = 3;
spacingX     = 0.8;
spacingY     = 0.2;
fontSize     = 8;
fontName     = 'Segoe UI';
xLimitsL = [9.2 10.2+1e-3];
xLimitsR = [5.5 6.5];

% Generation of Figure 1C
figure('Units','centimeters','Position',[4 4 plotWidth plotHeight],'Color','w');
posSubplots = subplotPositions(plotWidth,plotHeight,marginLeft,marginRight,marginBottom,marginTop,nPlotX,nPlotY,spacingX,spacingY);
hAx(1) = axes('position',posSubplots{5},'FontSize',fontSize,'FontName',fontName,'Layer','top'); hold on; box on;
    plot(Disc.DataMech.t,Disc.DataMech.posMeas,'Color',plotColors(1),'LineWidth',1)
    hYLabel(1) = ylabel({'Angle','PF (rad) DF'});
    ylim([-1e-3 0.15+1e-3])
hAx(4) = axes('position',posSubplots{6},'FontSize',fontSize,'FontName',fontName,'Layer','top'); hold on; box on;
    plot(Cont.DataMech.t,Cont.DataMech.posMeas,'Color',plotColors(3),'LineWidth',1)
    ylim([-1e-3 0.15+1e-3])
hAx(2) = axes('position',posSubplots{3},'FontSize',fontSize,'FontName',fontName,'Layer','top'); hold on; box on;
    plot(Disc.DataEMG.t,Disc.DataEMG.sol,'Color',plotColors(1),'LineWidth',1);
    hYLabel(2) = ylabel({'SOL EMG','(nV)'});
    ylim([0 250])
hAx(5) = axes('position',posSubplots{4},'FontSize',fontSize,'FontName',fontName,'Layer','top'); hold on; box on;
    plot(Cont.DataEMG.t,Cont.DataEMG.sol,'Color',plotColors(3),'LineWidth',1);
    ylim([0 650])
hAx(3) = axes('position',posSubplots{1},'FontSize',fontSize,'FontName',fontName,'Layer','top'); hold on; box on;
    plot(Disc.DataMech.t,Disc.DataMech.tqMeas,'Color',plotColors(1),'LineWidth',1)
    hXLabel(1) = xlabel('Time (s)');
    hYLabel(3) = ylabel({'Torque','PF (Nm) DF'});
    ylim([-15 4])
hAx(6) = axes('position',posSubplots{2},'FontSize',fontSize,'FontName',fontName,'Layer','top'); hold on; box on;
    plot(Cont.DataMech.t,Cont.DataMech.tqMeas,'Color',plotColors(3),'LineWidth',1)
    hXLabel(2) = xlabel('Time (s)');
    ylim([-15 4])
linkaxes(hAx(1:3),'x');
set(hAx(3),'XLim',xLimitsL);
linkaxes(hAx(4:6),'x');
set(hAx(6),'XLim',xLimitsR);

% Plot manipulations & Add perturbation onset lines across entire set of subplots
visualStretchesL = find(Disc.MechEns.stretchIdxs > xLimitsL(1)*2048 & Disc.MechEns.stretchIdxs < xLimitsL(2)*2048);
visualStretchesR = find(Cont.MechEns.stretchIdxs > xLimitsR(1)*2048 & Cont.MechEns.stretchIdxs < xLimitsR(2)*2048);
for ii = 1:numel(hAx)
    if (any(ii == [1 2 4 5]))
        set(hAx(ii),'XTickLabel',[])
    end
    if (ii <= 3)
        hYLabel(ii).Position(1) = 8.98;
        for jj = 1:numel(visualStretchesL)
            plot(hAx(ii),[Disc.DataMech.t(Disc.MechEns.stretchIdxs(visualStretchesL(jj))) Disc.DataMech.t(Disc.MechEns.stretchIdxs(visualStretchesL(jj)))],get(hAx(ii),'ylim'),'--','Color',plotColors(10),'LineWidth',1,'HandleVisibility','off');
        end
    else
        for jj = 1:numel(visualStretchesR)
            plot(hAx(ii),[Cont.DataMech.t(Cont.MechEns.stretchIdxs(visualStretchesR(jj))) Cont.DataMech.t(Cont.MechEns.stretchIdxs(visualStretchesR(jj)))],get(hAx(ii),'ylim'),'--','Color',plotColors(10),'LineWidth',1,'HandleVisibility','off');
        end
    end
end
drawnow; for ii = 1:numel(hXLabel), hXLabel(ii).Position(2) = -22; end

% export_fig([cd '/Processed/OutcomeFigures/Fig1C_Timeseries'],'-pdf','-painters')

%% Figure 1D (Ensemble: EMG M1-M2 response)
% Settings
plotWidth    = 6.8;
plotHeight   = 3.4;
marginLeft   = 1;
marginRight  = 0.2;
marginBottom = 0.9;
marginTop    = 0.1;
nPlotX       = 1;
nPlotY       = 1;
fontSize     = 8;
fontName     = 'Segoe UI';
yLimits = [0 200];

% Generation of Figure 1D
figure('Units','centimeters','Position',[4 4 plotWidth plotHeight],'Color','w');
posSubplots = subplotPositions(plotWidth,plotHeight,marginLeft,marginRight,marginBottom,marginTop,nPlotX,nPlotY,spacingX,spacingY);
hAx = axes('position',posSubplots{1},'FontSize',fontSize,'FontName',fontName,'Layer','top'); hold on; box off;    
    patch(([AcrossSession(2).M1Window(1) AcrossSession(2).M1Window(1) AcrossSession(2).M1Window(2) AcrossSession(2).M1Window(2)])/2048,[yLimits(1) yLimits(2) yLimits(2) yLimits(1)],plotColors(10,'lightest'),'LineStyle','none');
    patch(([AcrossSession(2).M1Window(1) AcrossSession(2).M1Window(1):AcrossSession(2).M1Window(2) AcrossSession(2).M1Window(2)])/2048,[0 mean(Disc.EMGEns.rise.solReflex((AcrossSession(2).M1Window(1):AcrossSession(2).M1Window(2)),:),2)' 0],plotColors(1,'light'),'EdgeColor','none');
    plot((-204:246)/2048,mean([Disc.EMGEns.rise.solBack;Disc.EMGEns.rise.solReflex],2),'Color',plotColors(1),'LineWidth',1);
    plot([0 0],get(hAx,'ylim'),'--','Color',plotColors(10),'LineWidth',1,'HandleVisibility','off');
    hXLabel = xlabel('Time after perturbation (s)');
    hYLabel = ylabel({'SOL EMG (nV)'});
    xlim([-0.02 0.1]);
    ylim(yLimits)
    text(mean(AcrossSession(2).M1Window)/2048,160,'M1','FontSize',fontSize,'FontName',fontName,'HorizontalAlignment','center','VerticalAlignment','bottom');
    text(mean(AcrossSession(2).M1Window)/2048+0.02,160,'M2','FontSize',fontSize,'FontName',fontName,'HorizontalAlignment','center','VerticalAlignment','bottom');
    
% export_fig([cd '/Processed/OutcomeFigures/Fig1D_EMGEnsemble'],'-pdf','-painters')

%% Figure 2 (FeedbackTimingPerturbations)
% Settings
plotWidth    = 11.4;
plotHeight   = 5.1;
marginLeft   = 0.75;
marginRight  = 0.2;
marginBottom = 0.9;
marginTop    = 0.1;
nPlotX       = 2;
nPlotY       = 3;
spacingX     = 0.8;
spacingY     = 0.25;
fontSize     = 8;
fontName     = 'Segoe UI';
xLimitsD = 12+[0 5.5];
xLimitsC = 12+[0 12];
yLimitsD = [-1e-3 0.15+1e-3];
yLimitsC = [-1e-3 0.035+1e-3];

% Generation of Figure 2
figure('Units','centimeters','Position',[4 4 plotWidth plotHeight],'Color','w');
posSubplots = subplotPositions(plotWidth,plotHeight,marginLeft,marginRight,marginBottom,marginTop,nPlotX,nPlotY,spacingX,spacingY);
axes('position',posSubplots{3}.*[1 1 1 2]+[0 spacingY/plotHeight 0 0],'FontSize',fontSize,'FontName',fontName,'Layer','top'); hold on; box off;    
    plot(Disc.DataMech.t,Disc.DataMech.posMeas,'Color',plotColors(1),'LineWidth',1)
    xlim(xLimitsD); ylim(yLimitsD);
axes('position',posSubplots{4}.*[1 1 1 2]+[0 spacingY/plotHeight 0 0],'FontSize',fontSize,'FontName',fontName,'Layer','top'); hold on; box off;    
    plot(Disc.DataMech.t,Disc.DataMech.posMeas,'Color',plotColors(2),'LineWidth',1)
    xlim(xLimitsD); ylim(yLimitsD);
hAx = axes('position',posSubplots{1}.*[1 1 2 1]+[0 0 spacingX/plotWidth 0],'FontSize',fontSize,'FontName',fontName,'Layer','top'); hold on; box off;    
    plot(Cont.DataMech.t,Cont.DataMech.posMeas,'Color',plotColors(3),'LineWidth',1)
    xlim(xLimitsC); ylim(yLimitsC);
    xlabel('Time (s)');
    xticklabels(0:2:12)
    
% export_fig([cd '/Processed/OutcomeFigures/Fig2_FeedbackTimingPerturbations'],'-pdf','-painters')