% %% Clean Start (via conditioningAnalysis)
% clc, clearvars, close all;
% 
% %% Settings
% % Experiment and Subject IDs to-be processed
% Settings.experimentID = {'201906-07_ReplicateMrachacz','201908-09_PilotMonkeyBusiness','201911-12_PilotSystemIdentification'}; % Experiment identifier
% Settings.subjectID = [{'001','002','003'};{'004','005','006'};{'007','008','009'}]; % Subject identifier (padded to 3 numbers)
% % Experimental and processing settings (flags)
% Settings.feedbackMode = {'EMG','EMG','SysID'}; % Flag if feedback provided on 'EMG' or 'SysID'
% Settings.isPlot = 0; % Flag to generate plots during processing (if true)
% % Define data storage location
% dataCD = cd; fileSepIdxs = strfind(dataCD,filesep);
% dataCD = dataCD(1:fileSepIdxs(end)-1);
% 
% % Add folder with all shared functions
% addpath(genpath('Functions'));

%% Processing
% for mm = 1:numel(Settings.experimentID)
    % Clear all variables per Experiment
    clearvars -except mm dataCD Settings
    % Load across-session data
    load([dataCD '/Data/' Settings.experimentID{mm} '/Stretch_Acclimatization/AcrossSession.mat']);
    
    for ii = size(Settings.subjectID,1):-1:1
        %% General
        % Retrieve all experimental folders/files
        subjectDir = dir([dataCD '/Data/' Settings.experimentID{mm} '/Stretch_Baseline/']);
        % Retrieve path/name of all folders belonging to specific subject
        subjectDir = {subjectDir(cellfun(@any,regexp({subjectDir.name},['Subject' Settings.subjectID{mm,ii}]))).name}';

        %% H-M Recruitment curve
        % Pre-allocate (intermediate) outcome measures
        DataBaseline(ii,1).mMax = zeros(numel(subjectDir),1);

        for jj = 1:numel(subjectDir)
            % Retrieve path/name of all H-M recruitment curve trials
            dirContent = dir([dataCD '/Data/' Settings.experimentID{mm} '/Stretch_Baseline/' subjectDir{jj} '/E02_HMRecruitment/*.mat']);
            dirContent = {dirContent.name}';

            % Load last (=only or combined/correct) trial and process results
            load([dataCD '/Data/' Settings.experimentID{mm} '/Stretch_Baseline/' subjectDir{jj} '/E02_HMRecruitment/' dirContent{end}]);
            DataHM = calcHMCurve(OutputData.EMGData,OutputData.TrialSettings,OutputData.SessionSettings);
            DataBaseline(ii).mMax(jj) = max(mean(DataHM.mWaveSize,2));
        end

        %% Control Block
        % Pre-allocate (intermediate) outcome measures
        DataBaseline(ii).solBackBlockControl = cell(numel(subjectDir),1);
        DataBaseline(ii).solBackControl = zeros(numel(subjectDir),1);
        DataBaseline(ii).taBackBlockControl = cell(numel(subjectDir),1);
        DataBaseline(ii).taBackControl = zeros(numel(subjectDir),1);
        DataBaseline(ii).tqBackBlockControl = cell(numel(subjectDir),1);
        DataBaseline(ii).tqBackControl = zeros(numel(subjectDir),1);
        DataBaseline(ii).solM1BlockControl = cell(numel(subjectDir),1);
        DataBaseline(ii).solM1Control = zeros(numel(subjectDir),1);
        if (strcmp(Settings.feedbackMode{mm},'SysID'))
            DataBaseline(ii).ankleGControl = zeros(numel(subjectDir),1);
        end
        DataBaseline(ii).stimIntControl = zeros(numel(subjectDir),1);

        for jj = 1:numel(subjectDir)
            % Retrieve path/name of all Control trials
            dirContent = dir([dataCD '/Data/' Settings.experimentID{mm} '/Stretch_Baseline/' subjectDir{jj} '/E03_ControlTrials/*.mat']);
            dirContent = {dirContent.name}';

            % First trial contains the 'control' block
            load([dataCD '/Data/' Settings.experimentID{mm} '/Stretch_Baseline/' subjectDir{jj} '/E03_ControlTrials/' dirContent{1}]);
            % Process experimental block to EMG/Mechanical ensembled data
            EMGEns = processBlocktoEnsemble(OutputData.EMGData,OutputData.TrialSettings);
            MechEns = processMechtoEnsemble(OutputData.AchData,OutputData.TrialSettings,OutputData.SessionSettings);
            if (strcmp(OutputData.TrialSettings.feedbackMode,'SysID'))
                % Rough approximate offset between flush and thread
                correctedTrialIdxs = size(OutputData.AchData,1) - numel(OutputData.SysID.Reflexive) + OutputData.SysID.trialIdxs;
                % Remove transients from ensembled data
                MechEns = trimMechEnsemble(MechEns,OutputData.TrialSettings,correctedTrialIdxs);
                EMGEns = trimEMGEnsemble(EMGEns,OutputData.AchData,OutputData.EMGData,OutputData.TrialSettings,correctedTrialIdxs,MechEns.stretchIdxs);
            end
            % Plot stretch reflex ensemble data
            if (Settings.isPlot)
                OutputData.SessionSettings.AcrossSession.M1Window = AcrossSession(ii).M1Window;
                plotStretchEnsembles(EMGEns,OutputData.TrialSettings,OutputData.SessionSettings);
            end
            % Process ensembled data to (intermediate) outcome measures
            % SOL/TA background activity (mean before perturbation onset)
            DataBaseline(ii).solBackBlockControl{jj} = mean(EMGEns.rise.solBack)';
            DataBaseline(ii).taBackBlockControl{jj} = mean(EMGEns.rise.taBack)';
            if (strcmp(OutputData.TrialSettings.feedbackMode,'SysID'))
                % Tq background activity (timeseries) retrieved from online processing 
                MechEns.rise.tqBack = MechEns.rise.tqBack(:,ismember(EMGEns.stretchIdxs,EMGEns.stretchIdxsRed));
            end
            % Torque background activity (mean before perturbation onset)
            DataBaseline(ii).tqBackBlockControl{jj} = mean(MechEns.rise.tqBack)';
            % SOL M1 reflex response (rms within M1-window)
            DataBaseline(ii).solM1BlockControl{jj} = rms(max(EMGEns.rise.solReflex((AcrossSession(ii).M1Window(1):AcrossSession(ii).M1Window(2))+1,:) - mean(EMGEns.rise.solBack),0))';
            if (strcmp(OutputData.TrialSettings.feedbackMode,'EMG'))
                % Mean stimulation interval per block
                DataBaseline(ii).stimIntControl(jj) = mean(EMGEns.stimInterval);
            else
                % Mean reflexive joint impedance gain (G) per block
                DataBaseline(ii).ankleGControl(jj) = mean(-OutputData.SysID.Reflexive(OutputData.SysID.trialIdxs));
                % Mean stimulation interval per block
                DataBaseline(ii).stimIntControl(jj) = mean(diff(OutputData.SysID.trialIdxs)/OutputData.TrialSettings.fsAch);
            end
            % Compute mean per block for all measures
            DataBaseline(ii).solBackControl(jj) = mean(DataBaseline(ii).solBackBlockControl{jj});
            DataBaseline(ii).taBackControl(jj) = mean(DataBaseline(ii).taBackBlockControl{jj});
            DataBaseline(ii).tqBackControl(jj) = mean(DataBaseline(ii).tqBackBlockControl{jj});
            DataBaseline(ii).solM1Control(jj) = mean(DataBaseline(ii).solM1BlockControl{jj});
        end

        %% Conditioning Block
        % Pre-allocate (intermediate) outcome measures
        DataBaseline(ii).solBackBlockCond = cell(numel(subjectDir),3);
        DataBaseline(ii).solBackCond = zeros(numel(subjectDir),3);
        DataBaseline(ii).taBackBlockCond = cell(numel(subjectDir),3);
        DataBaseline(ii).taBackCond = zeros(numel(subjectDir),3);
        DataBaseline(ii).tqBackBlockCond = cell(numel(subjectDir),3);
        DataBaseline(ii).tqBackCond = zeros(numel(subjectDir),3);
        DataBaseline(ii).solM1BlockCond = cell(numel(subjectDir),3);
        DataBaseline(ii).solM1Cond = zeros(numel(subjectDir),3);
        if (strcmp(Settings.feedbackMode{mm},'SysID'))
            DataBaseline(ii).ankleGCond = zeros(numel(subjectDir),3);
            DataBaseline(ii).fbPerfCond = zeros(numel(subjectDir),3,75,2);
        end
        DataBaseline(ii).stimIntCond = zeros(numel(subjectDir),3);

        for jj = 1:numel(subjectDir)
            % Retrieve path/name of all Conditioning trials
            dirContent = dir([dataCD '/Data/' Settings.experimentID{mm} '/Stretch_Baseline/' subjectDir{jj} '/E03_ControlTrials/*.mat']);
            dirContent = {dirContent.name}';

            % Second-Fourth trial contains the 'conditioning' block
            for kk = 1:3
                load([dataCD '/Data/' Settings.experimentID{mm} '/Stretch_Baseline/' subjectDir{jj} '/E03_ControlTrials/' dirContent{kk+1}]);
                % Process experimental block to EMG/Mechanical ensembled data
                EMGEns = processBlocktoEnsemble(OutputData.EMGData,OutputData.TrialSettings);
                MechEns = processMechtoEnsemble(OutputData.AchData,OutputData.TrialSettings,OutputData.SessionSettings);
                if (strcmp(OutputData.TrialSettings.feedbackMode,'SysID'))
                    % Rough approximate offset between flush and thread
                    correctedTrialIdxs = size(OutputData.AchData,1) - numel(OutputData.SysID.Reflexive) + OutputData.SysID.trialIdxs;
                    % Remove transients from ensembled data
                    MechEns = trimMechEnsemble(MechEns,OutputData.TrialSettings,correctedTrialIdxs);
                    [EMGEns,~,trialIdxsEMG] = trimEMGEnsemble(EMGEns,OutputData.AchData,OutputData.EMGData,OutputData.TrialSettings,correctedTrialIdxs,MechEns.stretchIdxs);
                end
                % Plot stretch reflex ensemble data
                if (Settings.isPlot)
                    OutputData.SessionSettings.AcrossSession.M1Window = AcrossSession(ii).M1Window;
                    plotStretchEnsembles(EMGEns,OutputData.TrialSettings,OutputData.SessionSettings);
                end
                % Process ensembled data to (intermediate) outcome measures
                % SOL/TA background activity (mean before perturbation onset)
                DataBaseline(ii).solBackBlockCond{jj,kk} = mean(EMGEns.rise.solBack)';
                DataBaseline(ii).taBackBlockCond{jj,kk} = mean(EMGEns.rise.taBack)';
                if (strcmp(OutputData.TrialSettings.feedbackMode,'SysID'))
                    % Tq background activity (timeseries) retrieved from online processing
                    MechEns.rise.tqBack = MechEns.rise.tqBack(:,ismember(EMGEns.stretchIdxs,EMGEns.stretchIdxsRed));
                end
                % Torque background activity (mean before perturbation onset)
                DataBaseline(ii).tqBackBlockCond{jj,kk} = mean(MechEns.rise.tqBack)';
                % SOL M1 reflex response (rms within M1-window)
                DataBaseline(ii).solM1BlockCond{jj,kk} = rms(max(EMGEns.rise.solReflex((AcrossSession(ii).M1Window(1):AcrossSession(ii).M1Window(2))+1,:) - mean(EMGEns.rise.solBack),0))';
                if (strcmp(OutputData.TrialSettings.feedbackMode,'EMG'))
                    % Mean stimulation interval per block
                    DataBaseline(ii).stimIntCond(jj,kk) = mean(EMGEns.stimInterval);
                else
                    % Mean reflexive joint impedance gain (G) per block
                    DataBaseline(ii).ankleGCond(jj,kk) = mean(-OutputData.SysID.Reflexive(OutputData.SysID.trialIdxs));
                    % Mean stimulation interval per block
                    DataBaseline(ii).stimIntCond(jj,kk) = mean(diff(OutputData.SysID.trialIdxs)/OutputData.TrialSettings.fsAch);
                    % Store the EMG-based and impedance-based reflex magnitudes at each feedback instances within a block
                    stretchesPerTrial = EMGEns.stretchIdxsRed < trialIdxsEMG & EMGEns.stretchIdxsRed > [0 trialIdxsEMG(1:end-1)];
                    DataBaseline(ii).fbPerfCond(jj,kk,:,:) = [-OutputData.SysID.Reflexive(OutputData.SysID.trialIdxs), (DataBaseline(ii).solM1BlockCond{jj,kk}'*(stretchesPerTrial./sum(stretchesPerTrial)))'];
                end
                % Compute mean per block for all measures
                DataBaseline(ii).solBackCond(jj,kk) = mean(DataBaseline(ii).solBackBlockCond{jj,kk});
                DataBaseline(ii).taBackCond(jj,kk) = mean(DataBaseline(ii).taBackBlockCond{jj,kk});
                DataBaseline(ii).tqBackCond(jj,kk) = mean(DataBaseline(ii).tqBackBlockCond{jj,kk});
                DataBaseline(ii).solM1Cond(jj,kk) = mean(DataBaseline(ii).solM1BlockCond{jj,kk});
            end
        end

        %% Outcome Measures
        % Revise EMG artifact errors (replace with NaN)
        if (mm == 3)
            if (ii == 1) % S007_Baseline2_Block3: SOL
                DataBaseline(ii).solBackBlockCond{2,3} = NaN(size(DataBaseline(ii).solBackBlockCond{2,3}));
                DataBaseline(ii).solBackCond(2,3) = NaN;
                DataBaseline(ii).solM1BlockCond{2,3} = NaN(size(DataBaseline(ii).solM1BlockCond{2,3}));
                DataBaseline(ii).solM1Cond(2,3) = NaN;
                DataBaseline(ii).fbPerfCond(2,3,:,:) = NaN;
            elseif (ii == 2) % S008_Baseline6_Block2/3: SOL
                DataBaseline(ii).solBackBlockCond{6,2} = NaN(size(DataBaseline(ii).solBackBlockCond{6,2}));
                DataBaseline(ii).solBackCond(6,2) = NaN;
                DataBaseline(ii).solM1BlockCond{6,2} = NaN(size(DataBaseline(ii).solM1BlockCond{6,2}));
                DataBaseline(ii).solM1Cond(6,2) = NaN;
                DataBaseline(ii).fbPerfCond(6,2,:,:) = NaN;
                DataBaseline(ii).solBackBlockCond{6,3} = NaN(size(DataBaseline(ii).solBackBlockCond{6,3}));
                DataBaseline(ii).solBackCond(6,3) = NaN;
                DataBaseline(ii).solM1BlockCond{6,3} = NaN(size(DataBaseline(ii).solM1BlockCond{6,3}));
                DataBaseline(ii).solM1Cond(6,3) = NaN;
                DataBaseline(ii).fbPerfCond(6,3,:,:) = NaN;
            end
        end
        
        % Store all relevent measures used within the further data processing scripts in new Results-struct
        % Interstimulus time
        ResultsBaseline(ii,1).stimInterval = [DataBaseline(ii).stimIntControl, DataBaseline(ii).stimIntCond];
        % H-M Recruitment
        ResultsBaseline(ii).mMax = DataBaseline(ii).mMax;

        % SOL/TA/Torque Background Activity (per block and mean of block)
        ResultsBaseline(ii).solBackBlock = [DataBaseline(ii).solBackBlockControl, DataBaseline(ii).solBackBlockCond];
        ResultsBaseline(ii).solBack      = [DataBaseline(ii).solBackControl, DataBaseline(ii).solBackCond];
        ResultsBaseline(ii).taBackBlock  = [DataBaseline(ii).taBackBlockControl, DataBaseline(ii).taBackBlockCond];
        ResultsBaseline(ii).taBack       = [DataBaseline(ii).taBackControl, DataBaseline(ii).taBackCond];
        ResultsBaseline(ii).tqBackBlock  = [DataBaseline(ii).tqBackBlockControl, DataBaseline(ii).tqBackBlockCond];
        ResultsBaseline(ii).tqBack       = [DataBaseline(ii).tqBackControl, DataBaseline(ii).tqBackCond];

        % SOL M1 Reflexive Activity
        ResultsBaseline(ii).solM1 = [DataBaseline(ii).solM1Control, DataBaseline(ii).solM1Cond];
        % Normalized (100% baseline) SOL M1 per block (control and conditioned reflexes separately)
        ResultsBaseline(ii).solM1BlockControlNorm = cellfun(@(x) x/mean(DataBaseline(ii).solM1Control(2:6),'omitnan')*100,DataBaseline(ii).solM1BlockControl,'UniformOutput',false);
        ResultsBaseline(ii).solM1BlockCondNorm = cellfun(@(x) x/mean(mean(DataBaseline(ii).solM1Cond(2:6,:),2,'omitnan'),'omitnan')*100,DataBaseline(ii).solM1BlockCond,'UniformOutput',false);
        % Normalized (100% baseline SOL M1 mean of block
        ResultsBaseline(ii).solM1Norm = [DataBaseline(ii).solM1Control/mean(DataBaseline(ii).solM1Control(2:6),'omitnan'),DataBaseline(ii).solM1Cond/mean(mean(DataBaseline(ii).solM1Cond(2:6,:),2,'omitnan'),'omitnan')]*100;
        if (strcmp(Settings.feedbackMode{mm},'SysID'))
            % Reflexive gain G (+normalized 100% baseline)
            ResultsBaseline(ii).ankleG = [DataBaseline(ii).ankleGControl, DataBaseline(ii).ankleGCond];
            ResultsBaseline(ii).ankleGNorm = [DataBaseline(ii).ankleGControl/mean(DataBaseline(ii).ankleGControl(2:6),'omitnan'),DataBaseline(ii).ankleGCond/mean(mean(DataBaseline(ii).ankleGCond(2:6,:),2,'omitnan'),'omitnan')]*100;
            ResultsBaseline(ii).fbPerfCond = DataBaseline(ii).fbPerfCond;
        else % No reflexive gain G for first two participant groups
            ResultsBaseline(ii).ankleG = NaN(6,4);
            ResultsBaseline(ii).ankleGNorm = NaN(6,4);
            ResultsBaseline(ii).fbPerfCond = NaN(6,4,75,2);
        end
    end
% end